==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/plugins/GUITestBase/src/tests/common_scenarios/msa_editor/edit/GTTestsMSAEditorEdit.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
k
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef GTTESTS_MSA_EDITOR_EDIT_H_
#define GTTESTS_MSA_EDITOR_EDIT_H_

#include <harness/UGUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_msa_editor_edit {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_msa_editor_edit"

GUI_TEST_CLASS_DECLARATION(test_0001)
GUI_TEST_CLASS_DECLARATION(test_0001_1)
GUI_TEST_CLASS_DECLARATION(test_0001_2)

GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0003_1)
GUI_TEST_CLASS_DECLARATION(test_0003_2)

GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0004_1)
GUI_TEST_CLASS_DECLARATION(test_0004_2)

GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0005_1)
GUI_TEST_CLASS_DECLARATION(test_0005_2)

GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0006_1)
GUI_TEST_CLASS_DECLARATION(test_0006_2)

GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0007_1)

GUI_TEST_CLASS_DECLARATION(test_0008)
GUI_TEST_CLASS_DECLARATION(test_0008_1)

GUI_TEST_CLASS_DECLARATION(test_0009)
GUI_TEST_CLASS_DECLARATION(test_0009_1)
GUI_TEST_CLASS_DECLARATION(test_0009_2)

GUI_TEST_CLASS_DECLARATION(test_0010)

GUI_TEST_CLASS_DECLARATION(test_0011)
GUI_TEST_CLASS_DECLARATION(test_0011_1)
GUI_TEST_CLASS_DECLARATION(test_0011_2)
GUI_TEST_CLASS_DECLARATION(test_0011_3)

GUI_TEST_CLASS_DECLARATION(test_0012)

GUI_TEST_CLASS_DECLARATION(test_0013)
GUI_TEST_CLASS_DECLARATION(test_0013_1)
GUI_TEST_CLASS_DECLARATION(test_0013_2)

GUI_TEST_CLASS_DECLARATION(test_0014)
GUI_TEST_CLASS_DECLARATION(test_0015)

#undef GUI_TEST_SUITE
}  // namespace GUITest_common_scenarios_msa_editor_edit

}  // namespace U2

#endif  // GTTESTS_MSA_EDITOR_EDIT_H_

==> ugene_49.1+dfsg.orig.tar.xz: ugene-49.1/src/plugins/GUITestBase/src/tests/common_scenarios/msa_editor/edit/GTTestsMSAEditorEdit.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
k
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#pragma once

#include <harness/UGUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_msa_editor_edit {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_msa_editor_edit"

GUI_TEST_CLASS_DECLARATION(test_0001)
GUI_TEST_CLASS_DECLARATION(test_0001_1)
GUI_TEST_CLASS_DECLARATION(test_0001_2)
GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0003_1)
GUI_TEST_CLASS_DECLARATION(test_0003_2)
GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0004_1)
GUI_TEST_CLASS_DECLARATION(test_0004_2)
GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0005_1)
GUI_TEST_CLASS_DECLARATION(test_0005_2)
GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0006_1)
GUI_TEST_CLASS_DECLARATION(test_0006_2)
GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0007_1)
GUI_TEST_CLASS_DECLARATION(test_0008)
GUI_TEST_CLASS_DECLARATION(test_0008_1)
GUI_TEST_CLASS_DECLARATION(test_0009)
GUI_TEST_CLASS_DECLARATION(test_0009_1)
GUI_TEST_CLASS_DECLARATION(test_0009_2)
GUI_TEST_CLASS_DECLARATION(test_0010)
GUI_TEST_CLASS_DECLARATION(test_0011)
GUI_TEST_CLASS_DECLARATION(test_0011_1)
GUI_TEST_CLASS_DECLARATION(test_0011_2)
GUI_TEST_CLASS_DECLARATION(test_0011_3)
GUI_TEST_CLASS_DECLARATION(test_0012)
GUI_TEST_CLASS_DECLARATION(test_0013)
GUI_TEST_CLASS_DECLARATION(test_0013_1)
GUI_TEST_CLASS_DECLARATION(test_0013_2)
GUI_TEST_CLASS_DECLARATION(test_0014)
GUI_TEST_CLASS_DECLARATION(test_0015)
GUI_TEST_CLASS_DECLARATION(test_0016)

#undef GUI_TEST_SUITE
}  // namespace GUITest_common_scenarios_msa_editor_edit

}  // namespace U2
